@@ -17,16 +17,19 @@ class MaxReRuns(object):
         root = validator.factory('integer')
         return root
 
-    def on_task_start(self, task, config):
+    def on_process_start(self, task, config):
         self.default = task.max_reruns
-        task.max_reruns = config
+        try:
+            task.max_reruns = int(config)
+        except ValueError:
+            return  # The validator will catch this before the task actually runs
         log.debug('changing max task rerun variable to: %s' % config)
 
-    def on_task_exit(self, task, config):
+    def on_process_end(self, task, config):
         log.debug('restoring max task rerun variable to: %s' % self.default)
         task.max_reruns = self.default
 
-    on_task_abort = on_task_exit
+    on_task_abort = on_process_end
 
 
 register_plugin(MaxReRuns, 'max_reruns', api_ver=2)
